@@ -1,5 +1,6 @@
 #[cfg(windows)]
 mod virtual_processing;
+#[cfg(windows)]
 pub use virtual_processing::*;
 
 #[derive(Debug, Eq, PartialEq)]
@@ -17,6 +18,18 @@ pub enum Styles {
     BgColor256(u8)
 }
 
+/// Initialize the r256 for cross-platform support.
+///
+/// # Examples
+///
+/// ```
+/// r256::init();
+/// ```
+pub fn init() {
+    #[cfg(windows)]
+    enable_virtual_terminal_processing();
+}
+
 fn convert_to_string(style: &Styles) -> String {
     match style {
         Styles::Bold => String::from("\x1b[1m"),
